@@ -2,5 +2,5 @@ def main():
     raise NotImplementedError()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     main()
